@@ -286,7 +286,7 @@ sub do ( $self, $query, @args ) {    ## no critic qw[Subroutines::ProhibitBuilti
 
                 # check error
                 if ( defined $DBI::err ) {
-                    if ( defined $cb ) { $cb->( result( [ 500, $DBI::errstr ], rows => $rows ), $self, undef ); return $rows }
+                    if ( defined $cb ) { warn "DBI: $DBI::errstr"; $cb->( result( [ 500, $DBI::errstr ], rows => $rows ), $self, undef ); return $rows }
                     else               { die $DBI::errstr }
                 }
 
@@ -301,7 +301,7 @@ sub do ( $self, $query, @args ) {    ## no critic qw[Subroutines::ProhibitBuilti
             $sth = $query;
         }
         else {
-            if ( defined $cb ) { $cb->( result( [ 500, 'Invalid STH class' ], rows => $rows ), $self, undef ); return $rows }
+            if ( defined $cb ) { warn "DBI: $DBI::errstr"; $cb->( result( [ 500, 'Invalid STH class' ], rows => $rows ), $self, undef ); return $rows }
             else               { die 'Invalid STH class' }
         }
 
@@ -328,7 +328,7 @@ sub do ( $self, $query, @args ) {    ## no critic qw[Subroutines::ProhibitBuilti
 
         # check error
         if ( defined $DBI::err ) {
-            if ( defined $cb ) { $cb->( result( [ 500, $DBI::errstr ], rows => $rows ), $self, undef ); return $rows }
+            if ( defined $cb ) { warn "DBI: $DBI::errstr"; $cb->( result( [ 500, $DBI::errstr ], rows => $rows ), $self, undef ); return $rows }
             else               { die $DBI::errstr }
         }
 
@@ -352,7 +352,7 @@ sub do ( $self, $query, @args ) {    ## no critic qw[Subroutines::ProhibitBuilti
 
         # check error
         if ( defined $DBI::err ) {
-            if ( defined $cb ) { $cb->( result( [ 500, $DBI::errstr ], rows => $rows ), $self, undef ); return $rows }
+            if ( defined $cb ) { warn "DBI: $DBI::errstr"; $cb->( result( [ 500, $DBI::errstr ], rows => $rows ), $self, undef ); return $rows }
             else               { die $DBI::errstr }
         }
 
@@ -375,7 +375,7 @@ sub do ( $self, $query, @args ) {    ## no critic qw[Subroutines::ProhibitBuilti
 
             # prepare sth error
             if ( defined $DBI::err ) {
-                if ( defined $cb ) { $cb->( result( [ 500, $DBI::errstr ], rows => $rows ), $self, undef ); return $rows }
+                if ( defined $cb ) { warn "DBI: $DBI::errstr"; $cb->( result( [ 500, $DBI::errstr ], rows => $rows ), $self, undef ); return $rows }
                 else               { die $DBI::errstr }
             }
 
@@ -397,7 +397,7 @@ sub do ( $self, $query, @args ) {    ## no critic qw[Subroutines::ProhibitBuilti
 
             # execute error
             if ( defined $DBI::err ) {
-                if ( defined $cb ) { $cb->( result( [ 500, $DBI::errstr ], rows => $rows ), $self, undef ); return $rows }
+                if ( defined $cb ) { warn "DBI: $DBI::errstr"; $cb->( result( [ 500, $DBI::errstr ], rows => $rows ), $self, undef ); return $rows }
                 else               { die $DBI::errstr }
             }
 
@@ -418,7 +418,7 @@ sub selectall ( $self, @ ) {
 
     # check error
     if ( defined $DBI::err ) {
-        if ( defined $cb ) { $cb->( result( [ 500, $DBI::errstr ], rows => $rows ), $self, undef ); return }
+        if ( defined $cb ) { warn "DBI: $DBI::errstr"; $cb->( result( [ 500, $DBI::errstr ], rows => $rows ), $self, undef ); return }
         else               { die $DBI::errstr }
     }
 
@@ -433,7 +433,7 @@ sub selectall ( $self, @ ) {
 
         # check error
         if ( defined $DBI::err ) {
-            if ( defined $cb ) { $cb->( result( [ 500, $DBI::errstr ], rows => $rows ), $self, undef ); return }
+            if ( defined $cb ) { warn "DBI: $DBI::errstr"; $cb->( result( [ 500, $DBI::errstr ], rows => $rows ), $self, undef ); return }
             else               { die $DBI::errstr }
         }
 
@@ -455,7 +455,7 @@ sub selectall_arrayref ( $self, @ ) {
 
     # check error
     if ( defined $DBI::err ) {
-        if ( defined $cb ) { $cb->( result( [ 500, $DBI::errstr ], rows => $rows ), $self, undef ); return }
+        if ( defined $cb ) { warn "DBI: $DBI::errstr"; $cb->( result( [ 500, $DBI::errstr ], rows => $rows ), $self, undef ); return }
         else               { die $DBI::errstr }
     }
 
@@ -473,7 +473,7 @@ sub selectrow ( $self, @ ) {
 
     # check error
     if ( defined $DBI::err ) {
-        if ( defined $cb ) { $cb->( result( [ 500, $DBI::errstr ], rows => $rows ), $self, undef ); return }
+        if ( defined $cb ) { warn "DBI: $DBI::errstr"; $cb->( result( [ 500, $DBI::errstr ], rows => $rows ), $self, undef ); return }
         else               { die $DBI::errstr }
     }
 
@@ -491,7 +491,7 @@ sub selectrow_arrayref ( $self, @ ) {
 
     # check error
     if ( defined $DBI::err ) {
-        if ( defined $cb ) { $cb->( result( [ 500, $DBI::errstr ], rows => $rows ), $self, undef ); return }
+        if ( defined $cb ) { warn "DBI: $DBI::errstr"; $cb->( result( [ 500, $DBI::errstr ], rows => $rows ), $self, undef ); return }
         else               { die $DBI::errstr }
     }
 
@@ -510,7 +510,7 @@ sub selectcol ( $self, @ ) {
 
     # check error
     if ( defined $DBI::err ) {
-        if ( defined $cb ) { $cb->( result( [ 500, $DBI::errstr ], rows => $rows ), $self, undef ); return }
+        if ( defined $cb ) { warn "DBI: $DBI::errstr"; $cb->( result( [ 500, $DBI::errstr ], rows => $rows ), $self, undef ); return }
         else               { die $DBI::errstr }
     }
 
@@ -523,7 +523,7 @@ sub selectcol ( $self, @ ) {
     for my $col ( is_plain_arrayref $args->{col} ? $args->{col}->@* : $args->{col} ) {
         if ( looks_like_number $col) {
             if ( $col > $num_of_fields ) {
-                if ( defined $cb ) { $cb->( result( [ 500, qq[Invalid column index: "$col"] ], rows => $rows ), $self, undef ); return }
+                if ( defined $cb ) { warn "DBI: $DBI::errstr"; $cb->( result( [ 500, qq[Invalid column index: "$col"] ], rows => $rows ), $self, undef ); return }
                 else               { die qq[Invalid column index: "$col"] }
             }
 
@@ -533,7 +533,7 @@ sub selectcol ( $self, @ ) {
             $name2idx //= $sth->{NAME_hash};
 
             if ( !exists $name2idx->{$col} ) {
-                if ( defined $cb ) { $cb->( result( [ 500, qq[Invalid column name: "$col"] ], rows => $rows ), $self, undef ); return }
+                if ( defined $cb ) { warn "DBI: $DBI::errstr"; $cb->( result( [ 500, qq[Invalid column name: "$col"] ], rows => $rows ), $self, undef ); return }
                 else               { die qq[Invalid column name: "$col"] }
             }
 
@@ -554,7 +554,7 @@ sub begin_work ( $self, $cb = undef ) {
 
     # check error
     if ( defined $DBI::err ) {
-        if ( defined $cb ) { $cb->( result( [ 500, $DBI::errstr ] ), $self ); return }
+        if ( defined $cb ) { warn "DBI: $DBI::errstr"; $cb->( result( [ 500, $DBI::errstr ] ), $self ); return }
         else               { die $DBI::errstr }
     }
 
@@ -568,7 +568,7 @@ sub commit ( $self, $cb = undef ) {
 
     # check error
     if ( defined $DBI::err ) {
-        if ( defined $cb ) { $cb->( result( [ 500, $DBI::errstr ] ), $self ); return }
+        if ( defined $cb ) { warn "DBI: $DBI::errstr"; $cb->( result( [ 500, $DBI::errstr ] ), $self ); return }
         else               { die $DBI::errstr }
     }
 
@@ -582,7 +582,7 @@ sub rollback ( $self, $cb = undef ) {
 
     # check error
     if ( defined $DBI::err ) {
-        if ( defined $cb ) { $cb->( result( [ 500, $DBI::errstr ] ), $self ); return }
+        if ( defined $cb ) { warn "DBI: $DBI::errstr"; $cb->( result( [ 500, $DBI::errstr ] ), $self ); return }
         else               { die $DBI::errstr }
     }
 
